# -*- coding: utf-8 -*-
"""
Created on Thu Oct 26 13:08:10 2023

@author: vlandgraf
"""

import vic_eis
import numpy as np
import matplotlib.pyplot as plt

fig, ax1 = plt.subplots(figsize=(3.25, 3.25), dpi = 400)
d = 1.27

Temp_in_C = [50,60,70,80,90,100]
R = [1924.86319000325,
 1235.40538717,
 828.311381637226,
 576.668080164206,
 414.653158801649,
 348.482823384217]
     
     
R_2 = [2361.95014797247,
 1496.71098488324,
 994.591740887672,
 686.528785278635,
 488.684770253197,
 359.887154009108]

T_in_K = np.array([i+273.15 for i in Temp_in_C])
Conductivity = [vic_eis.get_conductivity(i,1.27, 0.08) for i in R]
Conductivity_2 = [vic_eis.get_conductivity(i,1.27, 0.08) for i in R_2]


con_average = np.array([np.mean([i,j]) for i,j in zip(Conductivity, Conductivity_2)])*T_in_K
con_error = [np.std([i,j]/np.sqrt(2)) for i,j in zip(Conductivity, Conductivity_2)]


(e_a, s_0, ea_err, s_0_err) = vic_eis.get_an_activation_energy(T_in_K, con_average, con_errors_absolute = con_error)


log_average_conductivity = np.log10(np.array(con_average))
error_for_log = np.array(con_error)/ np.array(con_average)

a,x_for_fit_line, y_for_fit_line = vic_eis.get_the_arrhenius_fit_line_for_origin([50+273.15,100+273.15], e_a,  s_0)

one_over_T = 1/np.array(T_in_K)

ax1.errorbar(one_over_T, log_average_conductivity, yerr=2*error_for_log, ms=2, linestyle='', marker='o', mfc='white', color=(0,255/255,127/255), label='disordered-Li$_{9}$S$_{3}$N')
ax1.plot(x_for_fit_line, y_for_fit_line, color=(0,255/255,127/255), lw=0.75)

# plt.minorticks_on()

# top_axis = plt.twiny()
# top_axis.set_xlim(plt.xlim())
# top_axis.set_xticks(one_over_T)
# top_axis.set_xticklabels([(1/i+273.15) for i in one_over_T])


ax1.set_xlabel('1000/T (K$^{-1}$)', size=9, labelpad=0)
ax1.set_ylabel('log$_{10}$(σT/S K cm$^{-1}$) ', size = 9, labelpad=0)
# plt.subplots_adjust(bottom=0.12)

################################################################################################################################
######################################################
########################################
####Now for the ordered cell

# R = [3047,
#      1919, 
#      1254, 
#      855, 
#      603.37, 
#      441
     
     
    
# ]

# R_2 = R

# Conductivity = [vic_eis.get_conductivity(i,1.27, 0.08) for i in R]
# Conductivity_2 = [vic_eis.get_conductivity(i,1.27, 0.08) for i in R_2]


# Conductivity = [vic_eis.get_conductivity(i,1.27, 0.08) for i in R]
# Conductivity_2 = [vic_eis.get_conductivity(i,1.27, 0.08) for i in R_2]


# con_average = np.array([np.mean([i,j]) for i,j in zip(Conductivity, Conductivity_2)])*T_in_K
# con_error = [np.std([i,j]/np.sqrt(2)) for i,j in zip(Conductivity, Conductivity_2)]

# vic_eis.get_an_activation_energy(T_in_K, con_average, con_errors_absolute = con_error)

# log_average_conductivity = np.log10(np.array(con_average))
# error_for_log = np.array(con_error)/ np.array(con_average)

# a,x_for_fit_line, y_for_fit_line = vic_eis.get_the_arrhenius_fit_line_for_origin([50+273.15,100+273.15], 0.4762595820678703, 69001.04060465544)

# ax1.errorbar(one_over_T, log_average_conductivity, yerr=2*error_for_log, ms=2, linestyle='', marker='o', mfc='white', color=(127/255,0/255,255/255), label='ordered-Li$_{9}$S$_{3}$N')
# ax1.plot(x_for_fit_line, y_for_fit_line, color=(127/255,0/255,255/255), lw=0.75)



# ##########################################General plot features
# ax1.set_ylim(-3, 0)
# # plt.xlim(2.65/1000,3.15/1000)
# ax1.legend(loc='upper right', fontsize=8, bbox_to_anchor=(0.98, 0.95), frameon=False )
# # plt.minorticks_on()

# ax1.set_xticks(one_over_T, [str(np.round(i*1000,2)) for i in one_over_T],minor=False)
# ax1.tick_params(
# axis='both',          # changes apply to the x-axis
#     which='both',# both major and minor ticks are affected
#     direction='in',
#     # bottom=False,      # ticks along the bottom edge are off
#     # top=False,         # ticks along the top edge are off)
#     labelsize = 8
# )

# ax2 = ax1.twiny()
# ax2.xaxis.tick_top()
# ax2.set_xticks(ax1.get_xticks())
# ax2.tick_params(
# axis='x',          # changes apply to the x-axis
#     which='both',# both major and minor ticks are affected
#     direction='in',
#     # bottom=False,      # ticks along the bottom edge are off
#     # top=False,         # ticks along the top edge are off)
#     labelsize = 8)
# ax2.set_xlim(ax1.get_xlim())
# ax2.set_xticklabels([str(1/x-273.15) for x in ax1.get_xticks()])
# ax2.set_xlabel('T (°C)', size=9)

# fig.savefig('Arrhenius_plot_2.eps', format='eps', pad_inches=0, transparent=True, bbox_inches = 'tight')